==> am_mod_grp_0_1.zip: am_mod_grp_0_1/components/grp/template/barnraiser_01/forum_topic.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<form action="index.php?amn=grp_forum_topic" method="post" name="frm" id="id_frm">
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />
<input type="hidden" name="topic_id" value="<?php if(isset($topic['topic_id'])) { echo $topic['topic_id'];}?>" />


<div class="col_main">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_topic'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p class="txt_item_title">
					<?php echo $topic['topic_title'];?><br />
				</p>
				
				<p>
					<?php echo $topic['topic_synopsis'];?><br />
				</p>
				
				<hr />
				
				<?php
				if (isset($subjects)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<?php
					foreach ($subjects as $key => $i):
					?>
					<tr>
						<td valign="middle" width="32">	
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="" /></a><br />
						</td>
						<td valign="top">
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><b><?php echo $i['subject_title'];?></b></a><br />
							<?php echo $i['subject_synopsis'];?><br />
						</td>
						<td valign="top" align="center">
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;identity_id=<?php echo $i['identity']['identity_id'];?>&amp;group_id=<?php echo $group['group_id'];?>">
							<?php echo $i['identity']['identity_nic'];?></a><br />
							<?php echo $this->date->formatDate($i['subject_create_datetime'], 1);?><br />				
						</td>
						<td valign="top" align="center">
							<?php echo $i['total_comments'];?>&nbsp;replies<br />
							
							<?php
							if (!empty($i['latest_comment'])) {
							?>
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>#comment_body_id_<?php echo $i['latest_comment'][0]['comment_id'];?>">latest</a><br />
							<?php echo $this->date->formatDate($i['latest_comment'][0]['comment_create_datetime'], 1);?><br />
							<?php }?>					
						</td>
						<td valign="top">
							<?php
							if (!empty($i['subject_locked'])) {
							?>
								<img src="<?php echo $template_path;?>img/locked.png" vspace="2" alt="<?php echo $lang['txt_alt_locked'];?>" border="0" title="<?php echo $lang['txt_locked'];?>" /><br />
							<?php }?>
								
							<?php
							if (!empty($i['subject_sticky'])) {
							?>
								<img src="<?php echo $template_path;?>img/sticky.png" vspace="2" alt="<?php echo $lang['txt_alt_sticky'];?>" border="0" title="<?php echo $lang['txt_sticky'];?>" /><br />
							<?php }?>
						</td>
					</tr>
					<tr>
						<td colspan="5">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_topic_coordinator'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($coordinator)) {
					$id_card_layout = "portrait";
					$id_card = $coordinator;
					include($template_path_core . 'inc/identity.inc.php');
				}
				?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_options'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<a href="index.php?amn=grp_forum_subject_edit&amp;group_id=<?php echo $group['group_id'];?>&amp;topic_id=<?php echo $topic['topic_id'];?>"><?php echo $lang['href_add_subject'];?></a><br />
					<?php 
					if (isset($_POST['search_text'])) {
					?>
						<a href="index.php?amn=grp_forum_topic&amp;group_id=<?php echo $group['group_id'];?>&amp;topic_id=<?php echo $topic['topic_id'];?>"><?php echo $lang['href_list_all'];?></a><br />
					<?php }?>
				</p>
				
				<p>
					<b><?php echo $lang['txt_search'];?></b><br />			
				</p>
				
				<p>
					<input type="text" name="search_text" value="<?php if (isset($_POST['search_text'])) { echo $_POST['search_text'];};?>" class="input1" /><br />
				</p>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="search" class="input_submit" value="<?php echo $lang['sub_search']; ?>" /><br />
				</p>
			</div>
		</div>
	</div>
	
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_topics'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($topics)) {
				foreach ($topics as $key => $i):
				?>
				<p>
					<?php
					if ($i['topic_id'] == $topic['topic_id']) {
					?>
					<?php echo $i['topic_title'];?><br />
					<?php
					}
					else {
					?>
					<a href="index.php?amn=grp_forum_topic&amp;group_id=<?php echo $group['group_id'];?>&amp;topic_id=<?php echo $i['topic_id'];?>"><?php echo $i['topic_title'];?></a><br />
					<?php }?>				
				</p>
				
				<?php
				endforeach;
				}
				?>
			</div>
		</div>
	</div>
</div>
</form>

==> am_mod_grp_0_3.zip: am_mod_grp_0_3/components/grp/template/barnraiser_01/forum_topic.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<form action="index.php?amn=grp_forum_topic" method="post" name="frm" id="id_frm">
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />
<input type="hidden" name="topic_id" value="<?php if(isset($topic['topic_id'])) { echo $topic['topic_id'];}?>" />


<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_topic'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p class="txt_item_title">
					<?php echo $topic['topic_title'];?><br />
				</p>
				
				<p>
					<?php echo $topic['topic_synopsis'];?><br />
				</p>
				
				<hr />
				
				<?php
				if (isset($subjects)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<?php
					foreach ($subjects as $key => $i):
					?>
					<tr>
						<td valign="middle" width="32">	
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="" /></a><br />
						</td>
						<td valign="top">
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><b><?php echo $i['subject_title'];?></b></a><br />
							<?php echo $i['subject_synopsis'];?><br />
						</td>
						<td valign="top" align="center">
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;identity_id=<?php echo $i['identity']['identity_id'];?>&amp;group_id=<?php echo $group['group_id'];?>">
							<?php echo $i['identity']['identity_nic'];?></a><br />
							<?php echo $this->date->formatDate($i['subject_create_datetime'], 1);?><br />				
						</td>
						<td valign="top" align="center">
							<?php echo $i['total_comments'];?>&nbsp;replies<br />
							
							<?php
							if (!empty($i['latest_comment'])) {
							?>
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>#comment_body_id_<?php echo $i['latest_comment'][0]['comment_id'];?>">latest</a><br />
							<?php echo $this->date->formatDate($i['latest_comment'][0]['comment_create_datetime'], 1);?><br />
							<?php }?>
						</td>
						<td valign="top">
							<?php
							if (!empty($i['subject_locked'])) {
							?>
								<img src="<?php echo $template_path;?>img/locked.png" vspace="2" alt="<?php echo $lang['txt_alt_locked'];?>" border="0" title="<?php echo $lang['txt_locked'];?>" /><br />
							<?php }?>
								
							<?php
							if (!empty($i['subject_sticky'])) {
							?>
								<img src="<?php echo $template_path;?>img/sticky.png" vspace="2" alt="<?php echo $lang['txt_alt_sticky'];?>" border="0" title="<?php echo $lang['txt_sticky'];?>" /><br />
							<?php }?>
						</td>
					</tr>
					<tr>
						<td colspan="5">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_topic_coordinator'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($coordinator)) {
					$id_card_layout = "portrait";
					$id_card = $coordinator;
					include($template_path_core . 'inc/identity.inc.php');
				}
				?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_options'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<a href="index.php?amn=grp_forum_subject_edit&amp;group_id=<?php echo $group['group_id'];?>&amp;topic_id=<?php echo $topic['topic_id'];?>"><?php echo $lang['href_add_subject'];?></a><br />
					<?php 
					if (isset($_POST['search_text'])) {
					?>
						<a href="index.php?amn=grp_forum_topic&amp;group_id=<?php echo $group['group_id'];?>&amp;topic_id=<?php echo $topic['topic_id'];?>"><?php echo $lang['href_list_all'];?></a><br />
					<?php }?>
				</p>
				
				<p>
					<b><?php echo $lang['txt_search'];?></b><br />
				</p>
				
				<p>
					<input type="text" name="search_text" value="<?php if (isset($_POST['search_text'])) { echo $_POST['search_text'];};?>" class="input1" /><br />
				</p>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="search" class="input_submit" value="<?php echo $lang['sub_search']; ?>" /><br />
				</p>
			</div>
		</div>
	</div>
	
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_topics'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($topics)) {
				foreach ($topics as $key => $i):
				?>
				<p>
					<?php
					if ($i['topic_id'] == $topic['topic_id']) {
					?>
					<?php echo $i['topic_title'];?><br />
					<?php
					}
					else {
					?>
					<a href="index.php?amn=grp_forum_topic&amp;group_id=<?php echo $group['group_id'];?>&amp;topic_id=<?php echo $i['topic_id'];?>"><?php echo $i['topic_title'];?></a><br />
					<?php }?>
				</p>
				
				<?php
				endforeach;
				}
				?>
			</div>
		</div>
	</div>
</div>
</form>
